@@ -2,7 +2,7 @@ import uuid
 from datetime import datetime
 from datetime import timedelta
 
-from sqlalchemy import Column, String, Integer, Float, Index
+from sqlalchemy import Column, String, Integer, Float, Index, DateTime
 from sqlalchemy import event, func
 from sqlalchemy import inspect, JSON, Boolean, UniqueConstraint
 from sqlalchemy.ext.declarative import declarative_base
@@ -299,15 +299,14 @@ class TrainedModel(Base):
     __tablename__ = "TrainedModel"
     __table_args__ = (Index("os_chain_feed_name_target_index", "chain", "feed", "name", "target"),)
 
-    id = Column(String(255), primary_key=True, nullable=False)
-    chain = Column(String(255), nullable=False)
-    name = Column(String(255), nullable=False)
-    feed = Column(String(255), nullable=False)
+    id = Column(String(50), primary_key=True, nullable=False)
+    chain = Column(String(25), nullable=False)
+    name = Column(String(50), nullable=False)
+    feed = Column(String(25), nullable=False)
     symbols = Column(JSON, nullable=False)
-    model_type = Column(String(255), nullable=False)
-    r2 = Column(Float, nullable=False)
-    rmse = Column(Float, nullable=False)
-    feature_count = Column(Float, nullable=True)
+    model_type = Column(String(25), nullable=False)
+
+    features = Column(JSON, nullable=False)
     target = Column(Integer, nullable=True)
     scaler_mean = Column(JSON, nullable=True)
     scaler_scale = Column(JSON, nullable=True)
@@ -316,27 +315,18 @@ class TrainedModel(Base):
     performance = Column(JSON, nullable=True, default={})
     ranking = Column(Integer, nullable=True, default=0)
     last_evaluation_voting_round = Column(Integer, nullable=True, default=0)
-    last_evaluation_time = Column(String(255), nullable=True, default='')
+    last_evaluation_time = Column(String(55), nullable=True, default='')
     running = Column(Integer, nullable=True, default=0)
     predicting = Column(Integer, nullable=True, default=0)
-    # Metrics columns
+    r2 = Column(Float, nullable=False)
+    rmse = Column(Float, nullable=False)
     running_r_squared = Column(Float, nullable=True, default=0)  # R² (R-squared) - Running evaluation metric
-    directional_accuracy = Column(Float, nullable=True)  # Directional Accuracy
-    overestimation_frequency = Column(Float, nullable=True)  # Overestimation Frequency
-    underestimation_frequency = Column(Float, nullable=True)  # Underestimation Frequency
-    average_overestimation_degree = Column(Float, nullable=True)  # Average Overestimation Degree
-    average_underestimation_degree = Column(Float, nullable=True)  # Average Underestimation Degree
+    running_rmse = Column(Float, nullable=True)  # Root Mean Squared Error (RMSE)
 
     correction_factor = Column(Float, nullable=True)  # Running Correction Factor (if applicable)
     avg_correction_error = Column(Float, nullable=True)  # Average Correction Error
     avg_last_n_corrections = Column(Float, nullable=True)  # Average of Last N Corrections
-
-    mae = Column(Float, nullable=True)  # Mean Absolute Error (MAE)
-    rmse_metric = Column(Float, nullable=True)  # Root Mean Squared Error (RMSE)
-    mape = Column(Float, nullable=True)  # Mean Absolute Percentage Error (MAPE)
-    prediction_stability = Column(Float, nullable=True)  # Prediction Stability (e.g., standard deviation)
-    complexity_penalty = Column(Float, nullable=True)  # Complexity Penalty (if applicable)
-    timestamp = Column(String(255), nullable=True)
+    timestamp = Column(String(55), nullable=True)
 
     def __repr__(self):
         return str(self.to_dict())
@@ -425,3 +415,30 @@ class Tick(Base):
         six_hours_ago = datetime.utcnow() - timedelta(seconds=180)  # 2 minutes
         session.query(Tick).filter(Tick.timestamp < six_hours_ago.isoformat()).delete()
         session.commit()
+
+
+class EvaluatedTarget(Base):
+    __tablename__ = "EvaluatedTarget"
+    __table_args__ = (
+        UniqueConstraint('chain', 'model', name='uq_evaluated'),
+        Index("et_chain_model_index", "chain", "model"),
+    )
+    # Change `id` to an auto-incrementing integer primary key
+    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False)
+    chain = Column(String(15), nullable=True)
+    model = Column(String(50), nullable=False)
+    target = Column(String(50), nullable=True)
+    feed = Column(String(25), nullable=True)
+    correction_factor = Column(Float, nullable=True)  # Correction Factor. Typically, the last observed Moving Average.
+    correction_r2_score = Column(Float, nullable=True)
+    correction_rmse_score = Column(Float, nullable=True)
+    evaluation_voting_round = Column(Integer, nullable=True)
+    status = Column(Integer, nullable=True)
+    # Timestamp with default UTC now
+    timestamp = Column(DateTime, default=datetime.utcnow, nullable=False)
+
+    def __repr__(self):
+        return str(self.to_dict())
+
+    def to_dict(self):
+        return {c.key: getattr(self, c.key) for c in inspect(self).mapper.column_attrs}
\ No newline at end of file
